/**
 * Copyright 2023 actions-toolkit authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import * as exec from '@actions/exec';

export class Git {
  public static async getRemoteSha(repo: string, ref: string): Promise<string> {
    return await exec
      .getExecOutput(`git`, ['ls-remote', repo, ref], {
        ignoreReturnCode: true,
        silent: true
      })
      .then(res => {
        if (res.stderr.length > 0 && res.exitCode != 0) {
          throw new Error(res.stderr);
        }
        const [rsha] = res.stdout.trim().split(/[\s\t]/);
        if (rsha.length == 0) {
          throw new Error(`Cannot find remote ref for ${repo}#${ref}`);
        }
        return rsha;
      });
  }
}
